@@ -1,9 +1,9 @@
-version = "1.34.0"
+version = "1.35.0"
 
 # tools
 dblatex = ''
 fop = ''
-pkg_config = '/usr/bin/x86_64-pc-cygwin-pkg-config'
+pkg_config = '/usr/bin/pkg-config'
 xsltproc = '/usr/bin/xsltproc'
 
 # configured directories
@@ -11,4 +11,4 @@ prefix = '/usr'
 datarootdir = "${prefix}/share".replace('${prefix}', prefix)
 datadir = "${datarootdir}".replace('${datarootdir}', datarootdir)
 
-exeext = '.exe'
+exeext = ''
